/*-----------------------------------------------------------------------------    
* Copyright (C) 2010-2014 ARM Limited. All rights reserved.    
*    
* $Date:        12. March 2014
* $Revision: 	V1.4.4
*    
* Project: 	    CMSIS DSP Library    
* Title:        arm_fir_lattice_init_f32.c    
*    
* Description:  Floating-point FIR Lattice filter initialization function.    
*    
* Target Processor: Cortex-M4/Cortex-M3/Cortex-M0
*  
* ---------------------------------------------------------------------------*/

#include "arm_math.h"

 // * @ingroup groupFilters    

 // * @addtogroup FIR_Lattice    

/**    
 * @brief Initialization function for the floating-point FIR lattice filter.    
 * @param[in] *S points to an instance of the floating-point FIR lattice structure.    
 * @param[in] numStages  number of filter stages.    
 * @param[in] *pCoeffs points to the coefficient buffer.  The array is of length numStages.    
 * @param[in] *pState points to the state buffer.  The array is of length numStages.    
 * @return none.    
 */

void arm_fir_lattice_init_f32(
  arm_fir_lattice_instance_f32 * S,
  uint16_t numStages,
  float32_t * pCoeffs,
  float32_t * pState)
{
  // Assign filter taps 
  S->numStages = numStages;

  // Assign coefficient pointer 
  S->pCoeffs = pCoeffs;

  // Clear state buffer and size is always numStages 
  memset(pState, 0, (numStages) * sizeof(float32_t));

  // Assign state pointer 
  S->pState = pState;

}

 // *  end of FIR_Lattice group    
