/* ----------------------------------------------------------------------    
* Copyright (C) 2010-2014 ARM Limited. All rights reserved.    
*    
* $Date:        31. July 2014
* $Revision: 	V1.4.4
*    
* Project: 	    CMSIS DSP Library    
* Title:        arm_mat_init_q31.c    
*    
* Description:	Q31 matrix initialization.    
* Target Processor: Cortex-M4/Cortex-M3/Cortex-M0
*  
* -------------------------------------------------------------------------- */


#include "arm_math.h"

 // * @ingroup groupMatrix    

 // * @defgroup MatrixInit Matrix Initialization    

 // * @addtogroup MatrixInit    

  /**    
   * @brief  Q31 matrix initialization.    
   * @param[in,out] *S             points to an instance of the floating-point matrix structure.    
   * @param[in]     nRows          number of rows in the matrix.    
   * @param[in]     nColumns       number of columns in the matrix.    
   * @param[in]     *pData	   points to the matrix data array.    
   * @return        none    
   */

void arm_mat_init_q31(
  arm_matrix_instance_q31 * S,
  uint16_t nRows,
  uint16_t nColumns,
  q31_t * pData)
{
  // Assign Number of Rows 
  S->numRows = nRows;

  // Assign Number of Columns 
  S->numCols = nColumns;

  // Assign Data pointer 
  S->pData = pData;
}

 // *  end of MatrixInit group    
