/**
  ******************************************************************************
  * @file    NVIC/NVIC_WFIMode/main.c 
  * @author  MCD Application Team
  * @version V1.1.2
  * @date    14-August-2015
  * @brief   Main program body
  ******************************************************************************
  */


// Includes ------------------------------------------------------------------
#include "main.h"

 // @addtogroup NVIC_WFIMode

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
__IO uint32_t LowPowerMode = 0;

// Private function prototypes -----------------------------------------------
void Delay(__IO uint32_t nCount);

// Private functions ---------------------------------------------------------

/**
  * @brief  Main program.
  * @param  None
  * @retval None
  */
int main(void)
{
  /*!< At this stage the microcontroller clock setting is already configured, 
       this is done through SystemInit() function which is called from startup
       file (startup_stm32f30x.s) before to branch to application main.
       To reconfigure the default setting of SystemInit() function, refer to
       system_stm32f30x.c file
     */
   
  // Initialize Led and KEY Button mounted on STM32303C-EVAL        
  STM_EVAL_LEDInit(LED3);

  // Configure KEY button in EXTI mode   
  STM_EVAL_PBInit(BUTTON_KEY, BUTTON_MODE_EXTI); 
  
  while (1)
  {
    if(LowPowerMode == 1)
    {
      // Turn Off LED3 
      STM_EVAL_LEDOff(LED3);

      // Request to enter WFI mode 
      __WFI();
      LowPowerMode = 0;
    }

    Delay(0xFFFFF);
    STM_EVAL_LEDToggle(LED3);
  }
}

/**
  * @brief  Inserts a delay time.
  * @param  nCount: specifies the delay time length.
  * @retval None
  */
void Delay(__IO uint32_t nCount)
{
  for(; nCount != 0; nCount--);
}

#ifdef  USE_FULL_ASSERT

/**
  * @brief  Reports the name of the source file and the source line number
  *         where the assert_param error has occurred.
  * @param  file: pointer to the source file name
  * @param  line: assert_param error line source number
  * @retval None
  */
void assert_failed(uint8_t* file, uint32_t line)
{ 
  /* User can add his own implementation to report the file name and line number,
     ex: printf("Wrong parameters value: file %s on line %d\r\n", file, line) */

  // Infinite loop 
  while (1)
  {
  }
}
#endif



