/**
  ******************************************************************************
  * @file    RCC/RCC_Example/stm32f30x_it.c 
  * @author  MCD Application Team
  * @version V1.1.2
  * @date    14-August-2015
  * @brief   Main Interrupt Service Routines.
  ******************************************************************************
  */

// Includes ------------------------------------------------------------------
#include "stm32f30x_it.h"

 // @addtogroup STM32F30x_StdPeriph_Examples

 // @addtogroup RCC_Example

// Private typedef -----------------------------------------------------------
// Private define ------------------------------------------------------------
// Private macro -------------------------------------------------------------
// Private variables ---------------------------------------------------------
// Private function prototypes -----------------------------------------------
// Private functions ---------------------------------------------------------

// Cortex-M4 Processor Exceptions Handlers                         

/**
  * @brief  This function handles NMI exception.
  * @param  None
  * @retval None
  */
void NMI_Handler(void)
{
  // This interrupt is generated when HSE clock fails 

  if (RCC_GetITStatus(RCC_IT_CSS) != RESET)
  {
    /* At this stage: HSE, PLL are disabled (but no change on PLL config) and HSI
       is selected as system clock source */

    // Enable HSE 
    RCC_HSEConfig(RCC_HSE_ON);

    // Enable HSE Ready and PLL Ready interrupts 
    RCC_ITConfig(RCC_IT_HSERDY | RCC_IT_PLLRDY, ENABLE);

    // Clear Clock Security System interrupt pending bit 
    RCC_ClearITPendingBit(RCC_IT_CSS);

    /* Once HSE clock recovers, the HSERDY interrupt is generated and in the RCC ISR
       routine the system clock will be reconfigured to its previous state (before
       HSE clock failure) */
  }
}

/**
  * @brief  This function handles Hard Fault exception.
  * @param  None
  * @retval None
  */
void HardFault_Handler(void)
{
  // Go to infinite loop when Hard Fault exception occurs 
  while (1)
  {
  }
}

/**
  * @brief  This function handles Memory Manage exception.
  * @param  None
  * @retval None
  */
void MemManage_Handler(void)
{
  // Go to infinite loop when Memory Manage exception occurs 
  while (1)
  {
  }
}

/**
  * @brief  This function handles Bus Fault exception.
  * @param  None
  * @retval None
  */
void BusFault_Handler(void)
{
  // Go to infinite loop when Bus Fault exception occurs 
  while (1)
  {
  }
}

/**
  * @brief  This function handles Usage Fault exception.
  * @param  None
  * @retval None
  */
void UsageFault_Handler(void)
{
  // Go to infinite loop when Usage Fault exception occurs 
  while (1)
  {
  }
}

/**
  * @brief  This function handles SVCall exception.
  * @param  None
  * @retval None
  */
void SVC_Handler(void)
{
}

/**
  * @brief  This function handles Debug Monitor exception.
  * @param  None
  * @retval None
  */
void DebugMon_Handler(void)
{
}

/**
  * @brief  This function handles PendSVC exception.
  * @param  None
  * @retval None
  */
void PendSV_Handler(void)
{
}

/**
  * @brief  This function handles SysTick Handler.
  * @param  None
  * @retval None
  */
void SysTick_Handler(void)
{
}

// STM32F30x Peripherals Interrupt Handlers                   
// Add here the Interrupt Handler for the used peripheral(s) (PPP), for the  
// available peripheral interrupt handler's name please refer to the startup 
// file (startup_stm32f30x.s).                                               

/**
  * @brief  This function handles RCC interrupt request. 
  * @param  None
  * @retval None
  */
void RCC_IRQHandler(void)
{
  if(RCC_GetITStatus(RCC_IT_HSERDY) != RESET)
  { 
    // Clear HSERDY interrupt pending bit 
    RCC_ClearITPendingBit(RCC_IT_HSERDY);

    // Check if the HSE clock is still available 
    if (RCC_GetFlagStatus(RCC_FLAG_HSERDY) != RESET)
    { 
      // Enable PLL: once the PLL is ready the PLLRDY interrupt is generated  
      RCC_PLLCmd(ENABLE);     
    }
  }

  if(RCC_GetITStatus(RCC_IT_PLLRDY) != RESET)
  { 
    // Clear PLLRDY interrupt pending bit 
    RCC_ClearITPendingBit(RCC_IT_PLLRDY);

    // Check if the PLL is still locked 
    if (RCC_GetFlagStatus(RCC_FLAG_PLLRDY) != RESET)
    { 
      // Select PLL as system clock source 
      RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);
    }
  }
}

/**
  * @brief  This function handles PPP interrupt request.
  * @param  None
  * @retval None
  */
/*void PPP_IRQHandler(void)
{
}*/



